==> ogre-13.1.1-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_portal_base.js <==
var class_ogre_1_1_portal_base =
[
    [ "PORTAL_TYPE", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69", [
      [ "PORTAL_TYPE_QUAD", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69a406ea7e75464164cb9227c29872f072f", null ],
      [ "PORTAL_TYPE_AABB", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69ac82b2db8007314e8f6cb45923defbe71", null ],
      [ "PORTAL_TYPE_SPHERE", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69a953cb7c12e4f645a3c70ad412fe3b46d", null ]
    ] ],
    [ "PortalIntersectResult", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09f", [
      [ "NO_INTERSECT", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fae9716fe774674d008d6288418eb1ae06", null ],
      [ "INTERSECT_NO_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fac86d25e01093df7f239369e6da44781f", null ],
      [ "INTERSECT_BACK_NO_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fa4a2577055175711add9982092c4be1df", null ],
      [ "INTERSECT_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fa557d5a78c67a645043eb4df14ac5382b", null ]
    ] ],
    [ "PortalBase", "class_ogre_1_1_portal_base.html#a855768a638b2d44148e9a54c470615b2", null ],
    [ "~PortalBase", "class_ogre_1_1_portal_base.html#a72e3e7ba12ef808cf5897840d1486902", null ],
    [ "getWorldBoundingBox", "class_ogre_1_1_portal_base.html#a294390b4718778ef4b3f20af67362954", null ],
    [ "getWorldBoundingSphere", "class_ogre_1_1_portal_base.html#a125962313e2a59e95179f629824bf1d9", null ],
    [ "setNode", "class_ogre_1_1_portal_base.html#a05c4b91cbe5f80f315b6820c209e4404", null ],
    [ "setCurrentHomeZone", "class_ogre_1_1_portal_base.html#a5e62c57508bd5019c37e0d8b9511d7e4", null ],
    [ "setNewHomeZone", "class_ogre_1_1_portal_base.html#a68b42f3ab26a6ffd40c8a2421b053bac", null ],
    [ "setCorner", "class_ogre_1_1_portal_base.html#a02110b4b9d0ddb498d384cf6f3ec8951", null ],
    [ "setCorners", "class_ogre_1_1_portal_base.html#a7d71049232173b0d58dbdc4d55ba8698", null ],
    [ "setDirection", "class_ogre_1_1_portal_base.html#a47bd5bd57cb5fa2076a1f7848bf9b65f", null ],
    [ "calcDirectionAndRadius", "class_ogre_1_1_portal_base.html#a015feef401ddf609ac00f495956b7ddd", null ],
    [ "getType", "class_ogre_1_1_portal_base.html#acea589b146ca2d5f3167a6826ee6a53c", null ],
    [ "getRadius", "class_ogre_1_1_portal_base.html#ae7c133607d60374c600a2d44fd52bec7", null ],
    [ "getCurrentHomeZone", "class_ogre_1_1_portal_base.html#aeed3f211e08404aade41f16f7db23036", null ],
    [ "getNewHomeZone", "class_ogre_1_1_portal_base.html#a8cdd5dd1a1e72c692d5c6c11f62b9056", null ],
    [ "getCorner", "class_ogre_1_1_portal_base.html#a5f6513888aae8bff45bf47b229c9a6b8", null ],
    [ "getDirection", "class_ogre_1_1_portal_base.html#a468e1886f099a140f750aca9a437a670", null ],
    [ "getDerivedCorner", "class_ogre_1_1_portal_base.html#a4b8f189a0c307e8ce05e2c62a486115f", null ],
    [ "getDerivedDirection", "class_ogre_1_1_portal_base.html#a9bee49a94f617701c8ef2f744a614abe", null ],
    [ "getDerivedCP", "class_ogre_1_1_portal_base.html#affe5655a8bf636e27d9b734145736358", null ],
    [ "getDerivedSphere", "class_ogre_1_1_portal_base.html#a8f74aab16148fca9f4153b64a590fd31", null ],
    [ "getDerivedPlane", "class_ogre_1_1_portal_base.html#aac55c565a5032a3ce9c9a48fee23ebf6", null ],
    [ "getPrevDerivedCP", "class_ogre_1_1_portal_base.html#a60d0f20cccfc24f9f0221f912e01a241", null ],
    [ "getPrevDerivedPlane", "class_ogre_1_1_portal_base.html#a0ae708437e8708798abebb19d2e0a5cc", null ],
    [ "updateDerivedValues", "class_ogre_1_1_portal_base.html#a745c586d6aaf5739841fa78cd058f21b", null ],
    [ "adjustNodeToMatch", "class_ogre_1_1_portal_base.html#a80803987d260940345427116dcbc9574", null ],
    [ "setEnabled", "class_ogre_1_1_portal_base.html#affda9215a337abdea78b9529f7f888a6", null ],
    [ "getEnabled", "class_ogre_1_1_portal_base.html#a113fc83791e8c50ca6c57f5c7a39a4d1", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a8442cd8d86fdecfc5657184eba9ee696", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a7144c56ea2f0f8cb5dc6215c573aa8a1", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#ade881c14482443ed3139b657ea14ba6b", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a5cf356caed0ca1812cf442df2a27302d", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a040f340da1d8cead46d8543b73811df5", null ],
    [ "crossedPortal", "class_ogre_1_1_portal_base.html#a5cb47323a95b9298f1e706a52213fae1", null ],
    [ "closeTo", "class_ogre_1_1_portal_base.html#a34a188f0db37e579b37a83a59f7087fa", null ],
    [ "getBoundingBox", "class_ogre_1_1_portal_base.html#abfeeebac82a9430e878cde8213b21128", null ],
    [ "getBoundingRadius", "class_ogre_1_1_portal_base.html#aaa69ee72a4b964a115991cd58216dfbe", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_portal_base.html#a40b176a7a8ce0b25d8b129e3e4b632b4", null ],
    [ "visitRenderables", "class_ogre_1_1_portal_base.html#a98a5b2397142fe5c3799d0ca82c81ec8", null ],
    [ "_notifyMoved", "class_ogre_1_1_portal_base.html#a771d99cc1f7b16d289a9d023d8a60aa7", null ],
    [ "_notifyAttached", "class_ogre_1_1_portal_base.html#ad2cfb28e1ef786ed83ea88ac22675837", null ],
    [ "needUpdate", "class_ogre_1_1_portal_base.html#afa69136f2556f27d5fb455f2ea9a9e17", null ],
    [ "getCapsule", "class_ogre_1_1_portal_base.html#ad63e2c31229a74d54179b9693095ca22", null ],
    [ "getAAB", "class_ogre_1_1_portal_base.html#a8403ab6450e266d47f149a4c9248a719", null ]
];

==> ogre-13.4.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/class_ogre_1_1_portal_base.js <==
var class_ogre_1_1_portal_base =
[
    [ "PORTAL_TYPE", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69", [
      [ "PORTAL_TYPE_QUAD", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69a406ea7e75464164cb9227c29872f072f", null ],
      [ "PORTAL_TYPE_AABB", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69ac82b2db8007314e8f6cb45923defbe71", null ],
      [ "PORTAL_TYPE_SPHERE", "class_ogre_1_1_portal_base.html#a6f401ef1fa0213f68cfd5706c26bdc69a953cb7c12e4f645a3c70ad412fe3b46d", null ]
    ] ],
    [ "PortalIntersectResult", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09f", [
      [ "NO_INTERSECT", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fae9716fe774674d008d6288418eb1ae06", null ],
      [ "INTERSECT_NO_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fac86d25e01093df7f239369e6da44781f", null ],
      [ "INTERSECT_BACK_NO_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fa4a2577055175711add9982092c4be1df", null ],
      [ "INTERSECT_CROSS", "class_ogre_1_1_portal_base.html#aed7b889a1e10f9816c83127d0e13f09fa557d5a78c67a645043eb4df14ac5382b", null ]
    ] ],
    [ "PortalBase", "class_ogre_1_1_portal_base.html#a855768a638b2d44148e9a54c470615b2", null ],
    [ "~PortalBase", "class_ogre_1_1_portal_base.html#a72e3e7ba12ef808cf5897840d1486902", null ],
    [ "getWorldBoundingBox", "class_ogre_1_1_portal_base.html#a294390b4718778ef4b3f20af67362954", null ],
    [ "getWorldBoundingSphere", "class_ogre_1_1_portal_base.html#a125962313e2a59e95179f629824bf1d9", null ],
    [ "setNode", "class_ogre_1_1_portal_base.html#a05c4b91cbe5f80f315b6820c209e4404", null ],
    [ "setCurrentHomeZone", "class_ogre_1_1_portal_base.html#a5e62c57508bd5019c37e0d8b9511d7e4", null ],
    [ "setNewHomeZone", "class_ogre_1_1_portal_base.html#a68b42f3ab26a6ffd40c8a2421b053bac", null ],
    [ "setCorner", "class_ogre_1_1_portal_base.html#a02110b4b9d0ddb498d384cf6f3ec8951", null ],
    [ "setCorners", "class_ogre_1_1_portal_base.html#a7d71049232173b0d58dbdc4d55ba8698", null ],
    [ "setDirection", "class_ogre_1_1_portal_base.html#a47bd5bd57cb5fa2076a1f7848bf9b65f", null ],
    [ "calcDirectionAndRadius", "class_ogre_1_1_portal_base.html#a015feef401ddf609ac00f495956b7ddd", null ],
    [ "getType", "class_ogre_1_1_portal_base.html#acea589b146ca2d5f3167a6826ee6a53c", null ],
    [ "getDerivedRadius", "class_ogre_1_1_portal_base.html#acdd49667a546ab60e47c0616e34e53cc", null ],
    [ "getCurrentHomeZone", "class_ogre_1_1_portal_base.html#aeed3f211e08404aade41f16f7db23036", null ],
    [ "getNewHomeZone", "class_ogre_1_1_portal_base.html#a8cdd5dd1a1e72c692d5c6c11f62b9056", null ],
    [ "getCorner", "class_ogre_1_1_portal_base.html#a5f6513888aae8bff45bf47b229c9a6b8", null ],
    [ "getDirection", "class_ogre_1_1_portal_base.html#a468e1886f099a140f750aca9a437a670", null ],
    [ "getDerivedCorner", "class_ogre_1_1_portal_base.html#a4b8f189a0c307e8ce05e2c62a486115f", null ],
    [ "getDerivedDirection", "class_ogre_1_1_portal_base.html#a9bee49a94f617701c8ef2f744a614abe", null ],
    [ "getDerivedCP", "class_ogre_1_1_portal_base.html#affe5655a8bf636e27d9b734145736358", null ],
    [ "getDerivedSphere", "class_ogre_1_1_portal_base.html#a8f74aab16148fca9f4153b64a590fd31", null ],
    [ "getDerivedPlane", "class_ogre_1_1_portal_base.html#aac55c565a5032a3ce9c9a48fee23ebf6", null ],
    [ "getPrevDerivedCP", "class_ogre_1_1_portal_base.html#a60d0f20cccfc24f9f0221f912e01a241", null ],
    [ "getPrevDerivedPlane", "class_ogre_1_1_portal_base.html#a0ae708437e8708798abebb19d2e0a5cc", null ],
    [ "updateDerivedValues", "class_ogre_1_1_portal_base.html#a745c586d6aaf5739841fa78cd058f21b", null ],
    [ "adjustNodeToMatch", "class_ogre_1_1_portal_base.html#a80803987d260940345427116dcbc9574", null ],
    [ "setEnabled", "class_ogre_1_1_portal_base.html#affda9215a337abdea78b9529f7f888a6", null ],
    [ "getEnabled", "class_ogre_1_1_portal_base.html#a113fc83791e8c50ca6c57f5c7a39a4d1", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a8442cd8d86fdecfc5657184eba9ee696", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a7144c56ea2f0f8cb5dc6215c573aa8a1", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#ade881c14482443ed3139b657ea14ba6b", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a5cf356caed0ca1812cf442df2a27302d", null ],
    [ "intersects", "class_ogre_1_1_portal_base.html#a040f340da1d8cead46d8543b73811df5", null ],
    [ "crossedPortal", "class_ogre_1_1_portal_base.html#a5cb47323a95b9298f1e706a52213fae1", null ],
    [ "closeTo", "class_ogre_1_1_portal_base.html#a34a188f0db37e579b37a83a59f7087fa", null ],
    [ "getBoundingBox", "class_ogre_1_1_portal_base.html#abfeeebac82a9430e878cde8213b21128", null ],
    [ "getBoundingRadius", "class_ogre_1_1_portal_base.html#aaa69ee72a4b964a115991cd58216dfbe", null ],
    [ "_updateRenderQueue", "class_ogre_1_1_portal_base.html#a40b176a7a8ce0b25d8b129e3e4b632b4", null ],
    [ "visitRenderables", "class_ogre_1_1_portal_base.html#a98a5b2397142fe5c3799d0ca82c81ec8", null ],
    [ "_notifyMoved", "class_ogre_1_1_portal_base.html#a771d99cc1f7b16d289a9d023d8a60aa7", null ],
    [ "_notifyAttached", "class_ogre_1_1_portal_base.html#ad2cfb28e1ef786ed83ea88ac22675837", null ],
    [ "needUpdate", "class_ogre_1_1_portal_base.html#afa69136f2556f27d5fb455f2ea9a9e17", null ],
    [ "getCapsule", "class_ogre_1_1_portal_base.html#ad63e2c31229a74d54179b9693095ca22", null ],
    [ "getAAB", "class_ogre_1_1_portal_base.html#a8403ab6450e266d47f149a4c9248a719", null ]
];
